Learn R Programming

shinytitle (version 0.1.0)

use_shiny_title: Enable shinytitle

Description

Add this function to the UI of a shiny application in order for you to be able to update the browser title.

Usage

use_shiny_title()

Arguments

Value

A script tag that enables shinytitle to work within a shiny app.

See Also

change_window_title flashing_window_title

Examples

Run this code
# NOT RUN {
if (interactive()) {
  library(shiny)

  ui <- fluidPage(
    title = "Initial Title",
    use_shiny_title(),
    actionButton("button", "Click me for a new title"),
  )

  server <- function(input, output, session) {
    observeEvent(input$button, {
      change_window_title(session, "New Title")
    })
  }

  shinyApp(ui, server)
}

# }

Run the code above in your browser using DataLab